@@ -24,20 +24,20 @@
  * SECTION:grl-caps
  * @short_description: Describes the capabilities of a source for a given
  * operation.
- * @see_also: #GrlOperationOptions, grl_metadata_source_get_caps()
+ * @see_also: #GrlOperationOptions, grl_source_get_caps()
  *
  * A #GrlCaps instance is here to help you know if a given set of operation
  * options is supported for a given operation.
  *
  * Here is an example of how this would be used.
  * |[
- * GrlCaps *caps = grl_metadata_source_get_caps (GRL_METADATA_SOURCE (my_source),
-                                                 GRL_OP_SEARCH);
-   GrlOperationOptions *supported_options;
-   if (grl_operation_options_obey_caps (my_options, caps, &supported_options, NULL))
-     grl_media_source_search (my_source, "blah", interesting_keys, my_options, ...);
-   else // only use a subset of the options we wanted to pass
-     grl_media_source_search (my_source, "blah", interesting_keys, supported_options, ...);
+ * GrlCaps *caps = grl_source_get_caps (GRL_SOURCE (my_source),
+ *                                      GRL_OP_SEARCH);
+ * GrlOperationOptions *supported_options;
+ * if (grl_operation_options_obey_caps (my_options, caps, &supported_options, NULL))
+ *   grl_media_source_search (my_source, "blah", interesting_keys, my_options, ...);
+ * else // only use a subset of the options we wanted to pass
+ *   grl_media_source_search (my_source, "blah", interesting_keys, supported_options, ...);
  * ]|
  *
  * A #GrlCaps can also be passed to grl_operation_options_new(). The created
@@ -141,7 +141,7 @@ grl_caps_test_option (GrlCaps *caps, const gchar *key, const GValue *value)
 {
   if (0 == g_strcmp0 (key, GRL_OPERATION_OPTION_SKIP)
       || 0 == g_strcmp0 (key, GRL_OPERATION_OPTION_COUNT)
-      || 0 == g_strcmp0 (key, GRL_OPERATION_OPTION_FLAGS))
+      || 0 == g_strcmp0 (key, GRL_OPERATION_OPTION_RESOLUTION_FLAGS))
     /* these options must always be handled by plugins */
     return TRUE;
 
