@@ -64,6 +64,7 @@ struct _GrlPluginPrivate {
   gboolean loaded;
   gboolean (*load_func) (GrlRegistry *, GrlPlugin *, GList *);
   void (*unload_func) (GrlPlugin *);
+  void (*register_keys_func) (GrlRegistry *, GrlPlugin *);
 };
 
 static void grl_plugin_finalize (GObject *object);
@@ -199,6 +200,23 @@ grl_plugin_set_unload_func (GrlPlugin *plugin,
   plugin->priv->unload_func = unload_function;
 }
 
+/*
+ * grl_plugin_set_register_keys_func:
+ * @plugin: a plugin
+ * @register_keys_function: a function
+ *
+ * Sets the function to be executed to register new
+ * metadata keys.
+ */
+void
+grl_plugin_set_register_keys_func (GrlPlugin *plugin,
+                                   gpointer   register_keys_function)
+{
+  g_return_if_fail (GRL_IS_PLUGIN (plugin));
+
+  plugin->priv->register_keys_func = register_keys_function;
+}
+
 /**
  * grl_plugin_load:
  * @plugin: a plugin
@@ -251,6 +269,26 @@ grl_plugin_unload (GrlPlugin *plugin)
   g_object_notify_by_pspec (G_OBJECT (plugin), properties[PROP_LOADED]);
 }
 
+/*
+ * grl_plugin_register_keys:
+ * @plugin: a plugin
+ *
+ * Register custom metadata keys for the plugin
+ */
+void
+grl_plugin_register_keys (GrlPlugin *plugin)
+{
+  GrlRegistry *registry;
+
+  g_return_if_fail (GRL_IS_PLUGIN (plugin));
+
+  registry = grl_registry_get_default ();
+
+  if (plugin->priv->register_keys_func) {
+    plugin->priv->register_keys_func (registry, plugin);
+  }
+}
+
 /*
  * grl_plugin_set_id:
  * @plugin: a plugin
