@@ -65,16 +65,10 @@ GRL_LOG_DOMAIN(registry_log_domain);
 #define LOCAL_NET_TAG      "net:local"
 #define INTERNET_NET_TAG   "net:internet"
 
-#ifdef HAVE_GIO_WITH_NETMON
 #define SET_INVISIBLE_SOURCE(src, val)                          \
   g_object_set_data(G_OBJECT(src), "invisible", GINT_TO_POINTER(val))
 #define SOURCE_IS_INVISIBLE(src)                                \
   GPOINTER_TO_INT(g_object_get_data(G_OBJECT(src), "invisible"))
-#else
-#define SET_INVISIBLE_SOURCE(src, val)
-#define SOURCE_IS_INVISIBLE(src)                                \
-  FALSE
-#endif /* HAVE_GIO_WITH_NETMON */
 
 #define GRL_REGISTRY_GET_PRIVATE(object)                        \
   (G_TYPE_INSTANCE_GET_PRIVATE((object),                        \
@@ -99,9 +93,7 @@ struct _GrlRegistryPrivate {
   GSList *allowed_plugins;
   gboolean all_plugins_preloaded;
   struct KeyIDHandler key_id_handler;
-#ifdef HAVE_GIO_WITH_NETMON
   GNetworkMonitor *netmon;
-#endif
 };
 
 static void grl_registry_setup_ranks (GrlRegistry *registry);
@@ -207,7 +199,6 @@ grl_registry_class_init (GrlRegistryClass *klass)
                  G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
-#ifdef HAVE_GIO_WITH_NETMON
 static void
 get_connectivity (GrlRegistry          *registry,
                   GNetworkConnectivity *connectivity,
@@ -299,7 +290,6 @@ network_changed_cb (GObject     *gobject,
     }
   }
 }
-#endif /* HAVE_GIO_WITH_NETMON */
 
 static void
 grl_registry_init (GrlRegistry *registry)
@@ -317,13 +307,11 @@ grl_registry_init (GrlRegistry *registry)
   registry->priv->system_keys =
     g_hash_table_new_full (g_str_hash, g_str_equal, NULL, (GDestroyNotify) g_param_spec_unref);
 
-#ifdef HAVE_GIO_WITH_NETMON
   registry->priv->netmon = g_network_monitor_get_default ();
   g_signal_connect (G_OBJECT (registry->priv->netmon), "notify::connectivity",
                     G_CALLBACK (network_changed_cb), registry);
   g_signal_connect (G_OBJECT (registry->priv->netmon), "notify::network-available",
                     G_CALLBACK (network_changed_cb), registry);
-#endif
 
   key_id_handler_init (&registry->priv->key_id_handler);
 
@@ -338,7 +326,6 @@ configs_free (GList *configs)
   g_list_free_full (configs, g_object_unref);
 }
 
-#ifdef HAVE_GIO_WITH_NETMON
 static void
 update_source_visibility (GrlRegistry *registry,
                           GrlSource   *source)
@@ -383,7 +370,6 @@ update_source_visibility (GrlRegistry *registry,
     }
   }
 }
-#endif /* HAVE_GIO_WITH_NETMON */
 
 static void
 config_source_rank (GrlRegistry *registry,
@@ -1140,10 +1126,8 @@ grl_registry_register_source (GrlRegistry *registry,
   /* Set source rank */
   set_source_rank (registry, source);
 
-#ifdef HAVE_GIO_WITH_NETMON
   /* Update whether it should be invisible */
   update_source_visibility (registry, source);
-#endif
 
   if (!SOURCE_IS_INVISIBLE(source))
     g_signal_emit (registry, registry_signals[SIG_SOURCE_ADDED], 0, source);
@@ -1217,6 +1201,32 @@ grl_registry_add_directory (GrlRegistry *registry,
   registry->priv->all_plugins_preloaded = FALSE;
 }
 
+static GrlPlugin *
+grl_registry_prepare_plugin_from_desc (GrlRegistry *registry,
+                                       GrlPluginDescriptor *plugin_desc)
+{
+  GrlPlugin *plugin;
+
+  if (!plugin_desc->plugin_init ||
+      !plugin_desc->plugin_id) {
+    GRL_WARNING ("Plugin descriptor is not valid");
+    return NULL;
+  }
+
+  plugin = g_object_new (GRL_TYPE_PLUGIN, NULL);
+  grl_plugin_set_id (plugin, plugin_desc->plugin_id);
+  grl_plugin_set_filename (plugin, plugin_desc->plugin_id);
+
+  grl_plugin_set_load_func (plugin, plugin_desc->plugin_init);
+  grl_plugin_set_unload_func (plugin, plugin_desc->plugin_deinit);
+  grl_plugin_set_register_keys_func (plugin, plugin_desc->plugin_register_keys);
+
+  /* Insert plugin ID as part of plugin information */
+  grl_plugin_set_info (plugin, GRL_PLUGIN_INFO_MODULE, plugin_desc->plugin_id);
+
+  return plugin;
+}
+
 static GrlPlugin *
 grl_registry_prepare_plugin (GrlRegistry *registry,
                              const gchar *library_filename,
@@ -1338,6 +1348,47 @@ grl_registry_load_plugin (GrlRegistry *registry,
          activate_plugin (registry, plugin, error);
 }
 
+/**
+ * grl_registry_load_plugin_from_desc: (skip)
+ * @registry: the registry instance
+ * @plugin_desc: the #GrlPluginDescriptor for the plugin
+ * @error: error return location or @NULL to ignore
+ *
+ * Loads the grilo plugin defined by @plugin_desc. This is
+ * used to load plugins that aren't shared libraries, and are
+ * built into applications.
+ *
+ * <example>
+ *   Minimal example for loading a builtin plugin, in C.
+ *   <programlisting>
+ *     static GrlPluginDescriptor descriptor = {
+ *       .plugin_id = "grl-example",
+ *       .plugin_init = grl_example_plugin_init,
+ *     };
+ *
+ *     grl_registry_load_plugin_from_desc (registry, &descriptor, &error);
+ *   </programlisting>
+ * </example>
+ *
+ * Returns: %TRUE if the plugin is initialised correctly
+ *
+ * Since: 0.2.15
+ */
+gboolean
+grl_registry_load_plugin_from_desc (GrlRegistry *registry,
+                                    GrlPluginDescriptor *plugin_desc,
+                                    GError **error)
+{
+  GrlPlugin *plugin;
+
+  plugin = grl_registry_prepare_plugin_from_desc (registry, plugin_desc);
+  if (!plugin)
+    return FALSE;
+
+  return register_keys_plugin (registry, plugin, error) &&
+         activate_plugin (registry, plugin, error);
+}
+
 /**
  * grl_registry_load_plugin_directory:
  * @registry: the registry instance
